@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0201';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -156,7 +156,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 SYNOPSIS
 
@@ -208,7 +208,7 @@ Default: C<2>
 
   $scale = $bassline->scale;
 
-The musical scale to use.
+The musical scale to use, based on a given chord (i.e. C<$_[0]> here).
 
 Default: C<sub { $_[0] =~ /^[A-G][#b]?m/ ? 'minor' : 'major' }>
 
